# Types Benchmark Tests

This benchmark contains performance testing of critical data structures in opendal types, currently including performance testing of Buffer.

## Run

```shell
cargo bench types --features tests
```
